All pastes #915646 Raw Edit

Untitled

public text v1 · immutable
#915646 ·published 2008-02-23 23:14 UTC
rendered paste body
nvidia-installer log file '/var/log/nvidia-installer.log'
creation time: Sat Feb 23 16:44:29 2008

option status:
  license pre-accepted    : false
  update                  : false
  force update            : false
  expert                  : false
  uninstall               : false
  driver info             : false
  precompiled interfaces  : true
  no ncurses color        : false
  query latest version    : false
  OpenGL header files     : true
  no questions            : false
  silent                  : false
  no recursion            : false
  no backup               : false
  kernel module only      : false
  sanity                  : false
  add this kernel         : false
  no runlevel check       : false
  no network              : false
  no ABI note             : false
  no RPMs                 : false
  no kernel module        : false
  force SELinux           : default
  no X server check       : false
  force tls               : (not specified)
  X install prefix        : (not specified)
  X library install path  : (not specified)
  X module install path   : (not specified)
  OpenGL install prefix   : (not specified)
  OpenGL install libdir   : (not specified)
  utility install prefix  : (not specified)
  utility install libdir  : (not specified)
  doc install prefix      : (not specified)
  kernel name             : (not specified)
  kernel include path     : (not specified)
  kernel source path      : /usr/src/linux-headers-2.6.22-14-generic
  kernel output path      : (not specified)
  kernel install path     : (not specified)
  proc mount point        : /proc
  ui                      : (not specified)
  tmpdir                  : /tmp
  ftp mirror              : ftp://download.nvidia.com
  RPM file list           : (not specified)

Using: nvidia-installer ncurses user interface
-> License accepted.
-> No precompiled kernel interface was found to match your kernel; would you li
   ke the installer to attempt to download a kernel interface for your kernel f
   rom the NVIDIA ftp site (ftp://download.nvidia.com)? (Answer: No)
-> No precompiled kernel interface was found to match your kernel; this means
   that the installer will need to compile a new kernel interface.
-> Performing CC sanity check with CC="cc".
-> Performing CC version check with CC="cc".
-> Using the kernel source path '/usr/src/linux-headers-2.6.22-14-generic' as
   specified by the '--kernel-source-path' commandline option.
-> Kernel source path: '/usr/src/linux-headers-2.6.22-14-generic'
-> Kernel output path: '/usr/src/linux-headers-2.6.22-14-generic'
-> Performing rivafb check.
-> Performing nvidiafb check.
-> Performing Xen check.
-> Cleaning kernel module build directory.
   executing: 'cd ./usr/src/nv; make clean'...
   rm -f -f nv.o nv-vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nvacpi.
   o nv.o nv-vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nvacpi.o nvidi
   a.mod.o
   rm -f -f build-in.o nv-linux.o *.d .*.{cmd,flags}
   rm -f -f nvidia.{o,ko,mod.{o,c}} nv_compiler.h *~
   rm -f -f stprof stprof.o symtab.h Modules.symvers
   rm -f -rf .tmp_versions
   rm -f Makefile
-> Building kernel module:
   executing: 'cd ./usr/src/nv; make module SYSSRC=/usr/src/linux-headers-2.6.2
   2-14-generic SYSOUT=/usr/src/linux-headers-2.6.22-14-generic'...
   sh ./conftest.sh "cc" "cc" /usr/src/linux-headers-2.6.22-14-generic /usr/src
   /linux-headers-2.6.22-14-generic cc_sanity_check full_output
   sh ./conftest.sh "cc" "cc" /usr/src/linux-headers-2.6.22-14-generic /usr/src
   /linux-headers-2.6.22-14-generic select_makefile full_output
   make --no-print-directory -f Makefile module
   
   NVIDIA: calling KBUILD...
   make CC=cc  KBUILD_VERBOSE=1 -C /usr/src/linux-headers-2.6.22-14-generic SUB
   DIRS=/tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv modules
   test -e include/linux/autoconf.h -a -e include/config/auto.conf || (		\
   	echo;								\
   	echo "  ERROR: Kernel configuration is invalid.";		\
   	echo "         include/linux/autoconf.h or include/config/auto.conf are mis
   sing.";	\
   	echo "         Run 'make oldconfig && make prepare' on kernel src to fix it
   .";	\
   	echo;								\
   	/bin/false)
   mkdir -p /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.tmp_ver
   sions
   rm -f /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.tmp_versio
   ns/*
   make -f scripts/Makefile.build obj=/tmp/selfgz8572/NVIDIA-Linux-x86-100.14.1
   1-pkg1/usr/src/nv
   echo \#define NV_COMPILER \"`cc -v 2>&1 | tail -n 1`\" > /tmp/selfgz8572/NVI
   DIA-Linux-x86-100.14.11-pkg1/usr/src/nv/nv_compiler.h
     cc -Wp,-MD,/tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.nv.
   o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KERNEL
   __ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-proto
   types -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -msoft-float
   -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2  -march=i586 -m
   tune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/asm-i386/
   mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclaration-aft
   er-statement -Wno-pointer-sign -I/tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-
   pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-subs
   cripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror  -O -fno-commo
   n -msoft-float          -MD   -Wsign-compare -Wno-cast-qual -Wno-e
   rror -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_VERSION_STRING
   =\"100.14.11\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIP
   LE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COU
   NT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_I
   NSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_
   PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT -DNV_
   VMAP_4_PRESENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(
   nv)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz8572/NVIDIA-Lin
   ux-x86-100.14.11-pkg1/usr/src/nv/.tmp_nv.o /tmp/selfgz8572/NVIDIA-Linux-x86-
   100.14.11-pkg1/usr/src/nv/nv.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv.c:14:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
     cc -Wp,-MD,/tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.nv-
   vm.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KER
   NEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-pr
   ototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -msoft-fl
   oat -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2  -march=i58
   6 -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/asm-i
   386/mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclaration
   -after-statement -Wno-pointer-sign -I/tmp/selfgz8572/NVIDIA-Linux-x86-100.14
   .11-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-
   subscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror  -O -fno-c
   ommon -msoft-float          -MD   -Wsign-compare -Wno-cast-qual -Wno-error -
   D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_VERSION_STRING=\"100
   .14.11\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRI
   DGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRE
   SENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_
   PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESEN
   T -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT -DNV_VMAP_4
   _PRESENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv_vm)
   "  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz8572/NVIDIA-Linux-
   x86-100.14.11-pkg1/usr/src/nv/.tmp_nv-vm.o /tmp/selfgz8572/NVIDIA-Linux-x86-
   100.14.11-pkg1/usr/src/nv/nv-vm.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-vm.c:14:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
     cc -Wp,-MD,/tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.os-
   agp.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KE
   RNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-p
   rototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -msoft-f
   loat -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2  -march=i5
   86 -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/asm-
   i386/mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclaratio
   n-after-statement -Wno-pointer-sign -I/tmp/selfgz8572/NVIDIA-Linux-x86-100.1
   4.11-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat 
   -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror  -O
   -fno-common -msoft-float          -MD   -Wsign-compare -Wno-cast-qual -Wno-e
   rror -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_VERSION_STRING
   =\"100.14.11\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIP
   LE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COU
   NT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_I
   NSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_
   PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT -DNV_
   VMAP_4_PRESENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(
   os_agp)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz8572/NVIDIA
   -Linux-x86-100.14.11-pkg1/usr/src/nv/.tmp_os-agp.o /tmp/selfgz8572/NVIDIA-Li
   nux-x86-100.14.11-pkg1/usr/src/nv/os-agp.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/os-agp.c:24:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
     cc -Wp,-MD,/tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.os-
   interface.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include 
   -D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wst
   rict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -m
   soft-float -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2  -ma
   rch=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclud
   e/asm-i386/mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdecl
   aration-after-statement -Wno-pointer-sign -I/tmp/selfgz8572
   /NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -
   Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-multi
   char  -Werror  -O -fno-common -msoft-float          -MD   -Wsign-compare -Wn
   o-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -
   DNV_VERSION_STRING=\"100.14.11\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUC
   T_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_
   SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE
   _PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DN
   V_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE
   _SEM_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BA
   SENAME=KBUILD_STR(os_interface)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -
   o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.tmp_os-interfa
   ce.o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/os-interface
   .c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/os-interface.c:26:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
     cc -Wp,-MD,/tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.os-
   registry.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -
   D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstr
   ict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -ms
   oft-float -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2  -mar
   ch=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude
   /asm-i386/mach-def
   ault -fomit-frame-pointer -g  -fno-stack-protector -Wdeclaration-after-state
   ment -Wno-pointer-sign -I/tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr
   /src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -
   Wparentheses -Wpointer-arith  -Wno-multichar  -Werror  -O -fno-common -msoft
   -float          -MD   -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERN
   EL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_VERSION_STRING=\"100.14.11\" -UD
   EBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_
   PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM
   _MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT
   -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE
   _PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT -DNV_VMAP_4_PRESENT  -DM
   ODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(os_registry)"  -D"K
   BUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz8572/NVIDIA-Linux-x86-100
   .14.11-pkg1/usr/src/nv/.tmp_os-regi
   stry.o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/os-registr
   y.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/os-registry.c:14:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
     cc -Wp,-MD,/tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.nv-
   i2c.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KE
   RNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-p
   rototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -msoft-f
   loat -mregparm=3 -freg-struct-return -mpreferred-stack-bou
   ndary=2  -march=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-arg
   s   -Iinclude/asm-i386/mach-default -fomit-frame-pointer -g  -fno-stack-prot
   ector -Wdeclaration-after-statement -Wno-pointer-sign -I/tmp/selfgz8572/NVID
   IA-Linux-x86-100.14.11-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswit
   ch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-multichar 
   -Werror  -O -fno-common -msoft-float          -MD   -Wsign-compare -Wno-cast
   -qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_VE
   RSION_STRING=\"100.14.11\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM
   -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_
   MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESEN
   T -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP
   _PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PR
   ESENT -DNV_VMAP_4_PRESENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=
   KBUILD_STR(nv_i2c)"  -D"KBUILD_MOD
   NAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pk
   g1/usr/src/nv/.tmp_nv-i2c.o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/
   usr/src/nv/nv-i2c.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-i2c.c:8:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
     cc -Wp,-MD,/tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.nva
   cpi.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KE
   RNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-p
   rototypes -Wno-trigraphs -fno-strict-aliasing -f
   no-common -O2 -pipe -msoft-float -mregparm=3 -freg-struct-return -mpreferred
   -stack-boundary=2  -march=i586 -mtune=generic -ffreestanding -maccumulate-ou
   tgoing-args   -Iinclude/asm-i386/mach-default -fomit-frame-pointer -g  -fno-
   stack-protector -Wdeclaration-after-statement -Wno-pointer-sign -I/tmp/selfg
   z8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-t
   ype -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-
   multichar  -Werror  -O -fno-common -msoft-float          -MD   -Wsign-compar
   e -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DN
   VRM -DNV_VERSION_STRING=\"100.14.11\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_
   STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT 
   -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_
   STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESEN
   T -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_ACQUIRE_CO
   NSOLE_SEM_PRESENT -DNV_VMAP_4_PRESEN
   T  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nvacpi)"  -D"
   KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz8572/NVIDIA-Linux-x86-10
   0.14.11-pkg1/usr/src/nv/.tmp_nvacpi.o /tmp/selfgz8572/NVIDIA-Linux-x86-100.1
   4.11-pkg1/usr/src/nv/nvacpi.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/sr
   c/nv/nvacpi.c:15:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
     ld -m elf_i386 -m elf_i386  -r -o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.
   11-pkg1/usr/src/nv/nvidia.o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/
   usr/src/nv/nv-kernel.o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/s
   rc/nv/nv.o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/nv-vm.
   o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/os-agp.o /tmp/s
   elfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/os-interface.o /tmp/sel
   fgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/os-registry.o /tmp/selfgz
   8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/nv-i2c.o /tmp/selfgz8572/NVI
   DIA-Linux-x86-100.14.11-pkg1/usr/src/nv/nvacpi.o
     Building modules, stage 2.
   make -f /usr/src/linux-headers-2.6.22-14-generic/scripts/Makefile.modpost
     scripts/mod/modpost -m -a -i /usr/src/linux-headers-2.6.22-14-generic/Modu
   le.symvers -I /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/Mod
   ule.symvers -o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/Mo
   dule.symvers -w
   WARNING: could not find /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/
   src/nv/.nv-kernel.o.cmd for /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/
   usr/src/nv/nv-kernel.o
     cc -Wp,-MD,/tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/.nvi
   dia.mod.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D
   __KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstri
   ct-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -mso
   ft-float -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2  -marc
   h=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/
   asm-i386/mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclar
   ation-after-statement -Wno-pointer-sign    -D"KBUILD_STR(s)=#s" -D"KBUILD_BA
   SENAME=KBUILD_STR(nvidia.mod)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -DMODU
   LE -c -o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/nvidia.m
   od.o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/nv/nvidia.mod.c
     ld -m elf_i386 -m elf_i386 -r -o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.1
   1-pkg1/usr/src/nv/nvidia.ko /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/
   usr/src/nv/nvidia.o /tmp/selfgz8572/NVIDIA-Linux-x86-100.14.11-pkg1/usr/src/
   nv/nvidia.mod.o
   NVIDIA: left KBUILD.
-> done.
-> Kernel module compilation complete.
ERROR: Unable to load the kernel module 'nvidia.ko'.  This happens most
       frequently when this kernel module was built against the wrong or
       improperly configured kernel sources, with a version of gcc that differs
       from the one used to build the target kernel, or if a driver such as
       rivafb/nvidiafb is present and prevents the NVIDIA kernel module from
       obtaining ownership of the NVIDIA graphics device(s).
       
       Please see the log entries 'Kernel module load error' and 'Kernel
       messages' at the end of the file '/var/log/nvidia-installer.log' for
       more information.
-> Kernel module load error: insmod: error inserting './usr/src/nv/nvidia.ko':
   -1 Invalid module format
-> Kernel messages:
   [   14.235306] EXT3 FS on sda5, internal journal
   [   15.148566] Using specific hotkey driver
   [   15.185071] input: Power Button (FF) as /class/input/input6
   [   15.185085] ACPI: Power Button (FF) [PWRF]
   [   15.185102] input: Power Button (CM) as /class/input/input7
   [   15.185110] ACPI: Power Button (CM) [PWRB]
   [   15.262561] ibm_acpi: ec object not found
   [   15.293699] No dock devices found.
   [   15.336794] pcc_acpi: loading...
   [   23.033762] ppdev: user-space parallel port driver
   [   23.107373] eth0: no IPv6 routers present
   [   23.188686] apm: BIOS version 1.2 Flags 0x07 (Driver version 1.16ac)
   [   23.188689] apm: disabled - APM is not SMP safe.
   [   24.062550] Capability LSM initialized
   [   24.352205] Bluetooth: Core ver 2.11
   [   24.352248] NET: Registered protocol family 31
   [   24.352249] Bluetooth: HCI device and connection manager initialized
   [   24.352251] Bluetooth: HCI socket layer initialized
   [   24.361225] Bluetooth: L2CAP ver 2.8
   [   24.361227] Bluetooth: L2CAP socket layer initialized
   [   24.417213] Bluetooth: RFCOMM socket layer initialized
   [   24.417218] Bluetooth: RFCOMM TTY layer initialized
   [   24.417219] Bluetooth: RFCOMM ver 1.8
   [   25.618540] input: G15 Extra Keys as /class/input/input8
   [  314.905333] nvidia: disagrees about version of symbol struct_module
ERROR: Installation has failed.  Please see the file
       '/var/log/nvidia-installer.log' for details.  You may find suggestions
       on fixing installation problems in the README available on the Linux
       driver download page at www.nvidia.com.